@@ -1,4 +1,5 @@
 use crate::ops::forc_init;
+use anyhow::Result;
 use clap::Parser;
 
 /// Create a new Forc project.
@@ -7,7 +8,7 @@ pub(crate) struct Command {
     project_name: String,
 }
 
-pub(crate) fn exec(command: Command) -> Result<(), String> {
+pub(crate) fn exec(command: Command) -> Result<()> {
     let project_name = command.project_name;
-    forc_init::init_new_project(project_name).map_err(|e| e.to_string())
+    forc_init::init_new_project(project_name).map_err(|e| e)
 }
