@@ -1,14 +1,16 @@
+use anyhow::Result;
 use clap::Parser;
 
 mod commands;
 use self::commands::{
-    addr2line, build, clean, deploy, explorer, format, init, json_abi, lsp, parse_bytecode, run,
-    test, update,
+    addr2line, build, clean, completions, deploy, explorer, format, init, json_abi, lsp,
+    parse_bytecode, run, test, update,
 };
 
 use addr2line::Command as Addr2LineCommand;
 pub use build::Command as BuildCommand;
 pub use clean::Command as CleanCommand;
+pub use completions::Command as CompletionsCommand;
 pub use deploy::Command as DeployCommand;
 pub use explorer::Command as ExplorerCommand;
 pub use format::Command as FormatCommand;
@@ -21,7 +23,7 @@ use test::Command as TestCommand;
 pub use update::Command as UpdateCommand;
 
 #[derive(Debug, Parser)]
-#[clap(name = "forc", about = "Fuel Orchestrator")]
+#[clap(name = "forc", about = "Fuel Orchestrator", version)]
 struct Opt {
     /// the command to run
     #[clap(subcommand)]
@@ -34,6 +36,8 @@ enum Forc {
     Addr2Line(Addr2LineCommand),
     Build(BuildCommand),
     Clean(CleanCommand),
+    #[clap(after_help = completions::COMPLETIONS_HELP)]
+    Completions(CompletionsCommand),
     Deploy(DeployCommand),
     Explorer(ExplorerCommand),
     #[clap(name = "fmt")]
@@ -47,12 +51,14 @@ enum Forc {
     Lsp(LspCommand),
 }
 
-pub(crate) async fn run_cli() -> Result<(), String> {
+pub(crate) async fn run_cli() -> Result<()> {
     let opt = Opt::parse();
+
     match opt.command {
         Forc::Addr2Line(command) => addr2line::exec(command),
         Forc::Build(command) => build::exec(command),
         Forc::Clean(command) => clean::exec(command),
+        Forc::Completions(command) => completions::exec(command),
         Forc::Deploy(command) => deploy::exec(command).await,
         Forc::Explorer(command) => explorer::exec(command).await,
         Forc::Format(command) => format::exec(command),
